package com.goldenwater.yjjt.service;

import com.goldenwater.yjjt.domain.YjjtStation;

import java.util.List;

public interface IYjjtStationService {

    List<YjjtStation> selectYjjtStationList(YjjtStation yjjtStation);

    YjjtStation selectYjjtStationByPk(String stcd, String year);

    int insertYjjtStation(YjjtStation yjjtStation);

    int updateYjjtStation(YjjtStation yjjtStation);

    int deleteYjjtStationByPk(String stcd, String year);

    int deleteYjjtStationByPks(List<YjjtStation> list);

    void importStation(List<YjjtStation> stationList);

    List<YjjtStation> selectYjjtStationAll();
}
